@@ -1,9 +1,9 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from .forms import FileuploadForm, MatchingForm
 from .views import DataImportView
 
 
-urlpatterns = patterns('',
+urlpatterns = [
     url(r'^$', DataImportView.as_view([FileuploadForm, MatchingForm]), name='tabimport'),
-)
+]
