@@ -2,12 +2,13 @@ import os
 
 from django.conf import settings
 from django.contrib import messages
-from django.contrib.formtools.wizard.views import SessionWizardView
 from django.core.files.storage import FileSystemStorage
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext as _
 
+from formtools.wizard.views import SessionWizardView
+
 from . import FileFactory
 
 
@@ -26,7 +27,8 @@ class DataImportView(SessionWizardView):
 
     def done(self, form_list, **kwargs):
         try:
-            created, modified = form_list[-1].import_data()
+            # Wrap form_list to workaround a Python 3 bug in django-formtools
+            created, modified = list(form_list)[-1].import_data()
         except Exception as e:
             if settings.DEBUG:
                 raise
